@@ -12,8 +12,7 @@ test_that("knitting works", {
   z <- rmarkdown::render("example_knitr.Rmd", run_pandoc = FALSE, quiet = TRUE)
   
   # check files exist
-  expect_equivalent(z, "example_knitr.knit.md", ignore_attr = TRUE)
-  # expect_true(file.exists("example_knitr.html"))
+  expect_equal(z, "example_knitr.knit.md", ignore_attr = TRUE)
   expect_true(file.exists("example_knitr_files/figure-html/one-1.png"))
   expect_true(file.exists("example_knitr_files/figure-html/two-2.png"))
   expect_true(file.size("example_knitr_files/figure-html/two-2.png") > 1000)
